Image and Pixel Classes and Methods
:::::::::::::::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 2

   repeatimages.rst
   imageAbstractions.rst
   pattern.rst
   changeColor.rst
   changeColorLoc.rst
   changeData.rst
   summary.rst
   Exercises.rst
   mixedupcode.rst
   writeCode.rst
